@@ -548,18 +548,19 @@ bonobo_help_display_cb (BonoboUIComponent *component,
 
 		if (cl->app_prefix)
 			prefix = g_strdup (cl->app_prefix);
-		else {
-			g_object_get (G_OBJECT (gnome_program_get ()),
-				      GNOME_PARAM_APP_PREFIX, &prefix, NULL);
-			if (!prefix)
-				g_object_get (G_OBJECT (gnome_program_get ()),
-					      GNOME_PARAM_GNOME_PREFIX, &prefix, NULL);
-		}
+		else
+			prefix = NULL;
 
-		/* sub-optimal, but what can you do */
 		if (prefix)
 			datadir = g_strdup_printf ("%s/share", prefix);
-		else
+
+ 		else {
+			datadir = NULL;
+			g_object_get (G_OBJECT (gnome_program_get ()),
+				      GNOME_PARAM_APP_DATADIR, &datadir, NULL);
+		}
+
+		if (!datadir) /* desparate fallback */
 			datadir = g_strdup (BONOBO_DATADIR);
 
 		cl->program = gnome_program_init (
